texinfo-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

branch master updated: Avoid duplication in @detailmenu master menu outp


From: Patrice Dumas
Subject: branch master updated: Avoid duplication in @detailmenu master menu output by pod2texi
Date: Sun, 17 Apr 2022 12:10:54 -0400

This is an automated email from the git hooks/post-receive script.

pertusus pushed a commit to branch master
in repository texinfo.

The following commit(s) were added to refs/heads/master by this push:
     new 5710c1e63f Avoid duplication in @detailmenu master menu output by 
pod2texi
5710c1e63f is described below

commit 5710c1e63f9a637de8417e5b6fbb76665365d014
Author: Patrice Dumas <pertusus@free.fr>
AuthorDate: Sun Apr 17 18:10:39 2022 +0200

    Avoid duplication in @detailmenu master menu output by pod2texi
    
    * Pod-Simple-Texinfo/pod2texi.pl (_fix_texinfo_tree): call
    Texinfo::Structuring::associate_internal_references() to have
    'normalized' keys set for menu entries.
    
    * tp/Texinfo/Transformations.pm
    (_normalized_entry_associated_internal_node): add a function for
    similar code.
    
    * tp/Texinfo/ParserNonXS.pm (_register_extra_menu_entry_information):
    no need to delete menu entry 'normalized' as it is not set.
    
    * tp/Texinfo/Structuring.pm, tp/Texinfo/ParserNonXS.pm: minor changes
    in code style, comments and POD.
---
 ChangeLog                                          | 18 +++++++
 Pod-Simple-Texinfo/pod2texi.pl                     | 10 +++-
 man/pod2texi.1                                     |  2 +-
 tp/TODO                                            |  7 ++-
 tp/Texinfo/Convert/Converter.pm                    |  6 +--
 tp/Texinfo/ParserNonXS.pm                          | 34 ++++++++----
 tp/Texinfo/Structuring.pm                          | 24 +++++----
 tp/Texinfo/Transformations.pm                      | 60 ++++++++++++++--------
 .../res_parser/formatting_singular/chapter.html    | 60 +++++++++++-----------
 9 files changed, 142 insertions(+), 79 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 4368e08287..d132af0a45 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,21 @@
+2022-04-17  Patrice Dumas  <pertusus@free.fr>
+
+       Avoid duplication in @detailmenu master menu output by pod2texi
+
+       * Pod-Simple-Texinfo/pod2texi.pl (_fix_texinfo_tree): call
+       Texinfo::Structuring::associate_internal_references() to have
+       'normalized' keys set for menu entries.
+
+       * tp/Texinfo/Transformations.pm
+       (_normalized_entry_associated_internal_node): add a function for
+       similar code.
+
+       * tp/Texinfo/ParserNonXS.pm (_register_extra_menu_entry_information):
+       no need to delete menu entry 'normalized' as it is not set.
+
+       * tp/Texinfo/Structuring.pm, tp/Texinfo/ParserNonXS.pm: minor changes
+       in code style, comments and POD.
+
 2022-04-14  Gavin Smith  <gavinsmith0123@gmail.com>
 
        ASCII_PUNCTUATION for some tests
diff --git a/Pod-Simple-Texinfo/pod2texi.pl b/Pod-Simple-Texinfo/pod2texi.pl
index e781926c56..0ea732504a 100755
--- a/Pod-Simple-Texinfo/pod2texi.pl
+++ b/Pod-Simple-Texinfo/pod2texi.pl
@@ -293,9 +293,17 @@ sub _fix_texinfo_tree($$$$;$)
   }
   my ($sectioning_root, $sections_list)
     = Texinfo::Structuring::sectioning_structure($registrar, $texi_parser, 
$tree);
+  my ($updated_labels, $updated_targets_list, $updated_nodes_list)
+        = $texi_parser->labels_information();
+  my $refs = $texi_parser->internal_references_information();
+  my $parser_information = $texi_parser->global_information();
+  # this is needed to set 'normalized' for menu entries, they are
+  # used in complete_tree_nodes_menus.
+  Texinfo::Structuring::associate_internal_references($registrar, $texi_parser,
+                                  $parser_information, $updated_labels, $refs);
   Texinfo::Transformations::complete_tree_nodes_menus($tree)
     if ($section_nodes);
-  Texinfo::Transformations::regenerate_master_menu($texi_parser, $labels)
+  Texinfo::Transformations::regenerate_master_menu($texi_parser, 
$updated_labels)
      if ($do_master_menu);
   return ($texi_parser, $tree);
 }
diff --git a/man/pod2texi.1 b/man/pod2texi.1
index 985cafda13..ebdd66c4bf 100644
--- a/man/pod2texi.1
+++ b/man/pod2texi.1
@@ -133,7 +133,7 @@
 .\" ========================================================================
 .\"
 .IX Title "POD2TEXI 1"
-.TH POD2TEXI 1 "2022-02-18" "perl v5.34.0" "User Contributed Perl 
Documentation"
+.TH POD2TEXI 1 "2022-04-17" "perl v5.34.0" "User Contributed Perl 
Documentation"
 .\" For nroff, turn off justification.  Always turn off hyphenation; it makes
 .\" way too many mistakes in technical documents.
 .if n .ad l
diff --git a/tp/TODO b/tp/TODO
index 7a5a532062..886deaca12 100644
--- a/tp/TODO
+++ b/tp/TODO
@@ -72,14 +72,17 @@ replaced, elided, elided_block types.
 extra->'comment_at_end' and extra->'spaces_after_argument'
 likely in many line commands
 
-'extra'->'isindex' for nodes.
-
 Other
 -----
 
 For converter writers,
 'output_init_conf' and 'converter_init_conf'.
 
+'translated_commands' in converters is not documented anywhere nor is there
+a clean way to set it from user code with an API.  Not urgent, as long as
+it is not possible for users to register translated strings and provide with
+translations.
+
 
 Delayed bugs
 ============
diff --git a/tp/Texinfo/Convert/Converter.pm b/tp/Texinfo/Convert/Converter.pm
index 67708e01b2..9b705b6d68 100644
--- a/tp/Texinfo/Convert/Converter.pm
+++ b/tp/Texinfo/Convert/Converter.pm
@@ -64,9 +64,9 @@ my %defaults = (
 
 # defaults for all converters that are not defined elsewhere.
 # undef values in general marks information passed by the caller that
-# is valid in the parser configuration initialization hash, but
-# is not considered as "configuration", and is available directly
-# in the converter, not through get_conf().
+# is valid in the parser initialization hash, but is not considered
+# as "configuration/customization". It is not available through get_conf()
+# but is available directly in the converter as a hash key.
 # FIXME separate the two types of information and check that those
 # items are not valid customization options?
 my %common_converters_defaults = (
diff --git a/tp/Texinfo/ParserNonXS.pm b/tp/Texinfo/ParserNonXS.pm
index a9ab0394be..490a079ce9 100644
--- a/tp/Texinfo/ParserNonXS.pm
+++ b/tp/Texinfo/ParserNonXS.pm
@@ -3677,7 +3677,6 @@ sub _register_extra_menu_entry_information($$;$)
           $self->_line_error(__("empty node name in menu entry"), 
$source_info);
         }
       } else {
-        delete $parsed_entry_node->{'normalized'};
         $current->{'extra'}->{'menu_entry_node'} = $parsed_entry_node;
       }
     } elsif ($arg->{'type'} eq 'menu_entry_description') {
@@ -6692,7 +6691,7 @@ of tree element.  Tree elements associated with an 
@-command have a
 C<cmdname> key holding the @-command name.  Tree elements corresponding
 to text fragments have a C<text> key holding the corresponding text.
 Finally, the last category is other elements, which in most cases have
-a I<type> key holding their name.  Text fragments and @-command elements
+a C<type> key holding their name.  Text fragments and @-command elements
 may also have an associated type when such information is needed.
 
 The children of an @-command or of other container element are in the array
@@ -6944,10 +6943,11 @@ leads to prepending text such as 'Function'.
 
 =back
 
-=head3 Types of container elements
+=head3 Tree container elements
 
-The other types of element are the following.  These are containers with
-other elements appearing in their C<contents>.
+Some types of element are containers of portions of the tree,
+either for the whole tree, or for contents appearing before C<@node>
+and sectioning commands.
 
 =over
 
@@ -6971,14 +6971,23 @@ Content before nodes and sectioning commands at the 
beginning of C<document_root
 This container holds everything appearing before the first content, including
 the C<\input texinfo.tex> line and following blank lines.
 
+=item preamble_before_setfilename
+
+This container holds everything that appears before C<@setfilename>.
+
 =item preamble_before_content
 
 This container holds everything appearing before the first formatted content,
 corresponding to the I<Texinfo preamble> in the Texinfo manual.
 
-=item preamble_before_setfilename
+=back
 
-This container holds everything that appears before C<@setfilename>.
+=head3 Types of container elements
+
+The other types of element are the following.  These are containers with
+other elements appearing in their C<contents>.
+
+=over
 
 =item paragraph
 
@@ -7008,10 +7017,10 @@ taking arguments surrounded by braces (and in some 
cases separated by
 commas).  I<brace_command_context> is used for @-commands with braces
 that start a new context (C<@footnote>, C<@caption>, C<@math>).
 
-I<line_arg> is used for commands that take the texinfo code on the
-rest of the line as their argument (for example (C<@settitle>, C<@node>,
-C<@section> and similar).  I<block_line_arg> is similar but is used for
-commands that start a new block (which is to be ended with C<@end>).
+I<line_arg> is used for commands that take the texinfo code on the rest of the
+line as their argument, such as C<@settitle>, C<@node>, C<@section>.
+I<block_line_arg> is similar but is used for commands that start a new block
+(which is to be ended with C<@end>).
 
 For example
 
@@ -7239,6 +7248,9 @@ if there is no sectioning command between the C<@part> 
and the node.
 A node containing a menu have a I<menus> key which refers to an array of
 references to menu elements occuring in the node.
 
+The first node containing a C<@printindex> @-command has the I<isindex>
+key set.
+
 =item C<@part>
 
 The next sectioning command tree element is in I<part_associated_section>.
diff --git a/tp/Texinfo/Transformations.pm b/tp/Texinfo/Transformations.pm
index 8cf0dee2de..a69d63af47 100644
--- a/tp/Texinfo/Transformations.pm
+++ b/tp/Texinfo/Transformations.pm
@@ -393,17 +393,17 @@ sub complete_node_menu($;$)
       foreach my $menu (@{$node->{'extra'}->{'menus'}}) {
         foreach my $entry (@{$menu->{'contents'}}) {
           if ($entry->{'type'} and $entry->{'type'} eq 'menu_entry') {
-            my $entry_node = $entry->{'extra'}->{'menu_entry_node'};
-            if (! $entry_node->{'manual_content'}
-                and defined($entry_node->{'normalized'})) {
-              $existing_entries{$entry_node->{'normalized'}}
+            my ($normalized_entry_node, $node)
+              = _normalized_entry_associated_internal_node($entry);
+            if (defined($normalized_entry_node)) {
+              $existing_entries{$normalized_entry_node}
                 = [$menu, $entry];
             }
           }
         }
       }
     }
-    #print STDERR join('|', keys(%existing_entries))."\n";
+    #print STDERR "existing_entries: ".join('|', keys(%existing_entries))."\n";
     my @pending;
     my $current_menu;
     foreach my $node_entry (@node_childs) {
@@ -433,7 +433,7 @@ sub complete_node_menu($;$)
       if (!$current_menu) {
         my $section = $node->{'extra'}->{'associated_section'};
         $current_menu =
-       Texinfo::Structuring::new_block_command (\@pending, $section, 'menu');
+          Texinfo::Structuring::new_block_command(\@pending, $section, 'menu');
         _prepend_new_menu_in_node_section($node, $section, $current_menu);
       } else {
         foreach my $entry (@pending) {
@@ -511,14 +511,11 @@ sub _print_down_menus($$)
       foreach my $entry (@{$menu->{'contents'}}) {
         if ($entry->{'type'} and $entry->{'type'} eq 'menu_entry') {
           push @master_menu_contents, Texinfo::Common::copy_tree($entry);
-          # gather node children to recusrsively print their menus
-          my $entry_node = $entry->{'extra'}->{'menu_entry_node'};
-          if (! $entry_node->{'manual_content'}
-              and defined($entry_node->{'normalized'})) {
-            my $node = $labels->{$entry_node->{'normalized'}};
-            if (defined($node) and $node->{'extra'}) {
-              push @node_children, $node;
-            }
+          # gather node children to recursively print their menus
+          my ($normalized_entry_node, $node)
+               = _normalized_entry_associated_internal_node($entry, $labels);
+          if (defined($node) and $node->{'extra'}) {
+            push @node_children, $node;
           }
         }
       }
@@ -565,6 +562,30 @@ if (0) {
   gdt(' --- The Detailed Node Listing ---');
 }
 
+sub _normalized_entry_associated_internal_node($;$)
+{
+  my $entry = shift;
+  my $labels = shift;
+
+  my $entry_node = $entry->{'extra'}->{'menu_entry_node'};
+  # 'normalized' is added by 
Texinfo::Structuring::associate_internal_references
+  # so it could be possible not to have 'normalized' set.  In that case, it 
could
+  # still be determined with NodeNameNormalization::normalize_node.
+  my $normalized_entry_node = $entry_node->{'normalized'};
+  #my $normalized_entry_node
+  #  = Texinfo::Convert::NodeNameNormalization::normalize_node(
+  #                   {'contents' => $entry_node->{'node_content'}});
+  if (! $entry_node->{'manual_content'}
+      and defined($normalized_entry_node)) {
+    if ($labels) {
+      return ($normalized_entry_node, $labels->{$normalized_entry_node});
+    } else {
+      return ($normalized_entry_node, undef);
+    }
+  }
+  return (undef, undef);
+}
+
 sub new_master_menu($$)
 {
   my $self = shift;
@@ -577,13 +598,10 @@ sub new_master_menu($$)
     foreach my $menu (@{$node->{'extra'}->{'menus'}}) {
       foreach my $entry (@{$menu->{'contents'}}) {
         if ($entry->{'type'} and $entry->{'type'} eq 'menu_entry') {
-          my $entry_node = $entry->{'extra'}->{'menu_entry_node'};
-          if (! $entry_node->{'manual_content'}
-              and defined($entry_node->{'normalized'})) {
-            my $node = $labels->{$entry_node->{'normalized'}};
-            if (defined($node) and $node->{'extra'}) {
-              push @master_menu_contents, _print_down_menus($node, $labels);
-            }
+          my ($normalized_entry_node, $node)
+               = _normalized_entry_associated_internal_node($entry, $labels);
+          if (defined($node) and $node->{'extra'}) {
+            push @master_menu_contents, _print_down_menus($node, $labels);
           }
         }
       }
diff --git a/tp/tests/tex_html/res_parser/formatting_singular/chapter.html 
b/tp/tests/tex_html/res_parser/formatting_singular/chapter.html
index 79436e05d1..0c124c9f23 100644
--- a/tp/tests/tex_html/res_parser/formatting_singular/chapter.html
+++ b/tp/tests/tex_html/res_parser/formatting_singular/chapter.html
@@ -1081,8 +1081,8 @@ but , ,
 <code class="code">@url{--a,}</code> <a class="url" href="--a">--a</a>
 <code class="code">@url{,--b}</code> &ndash;b
 <code class="code">@var{--a}</code> <var class="var">&ndash;a</var>
-<code class="code">@verb{:--a:}</code> <tt class="verb">--a</tt>
-<code class="code">@verb{:a  &lt; &amp; @ % &quot; --    b:}</code> <tt 
class="verb">a  &lt; &amp; @ % &quot; --    b</tt>
+<code class="code">@verb{:--a:}</code> <code class="verb">--a</code>
+<code class="code">@verb{:a  &lt; &amp; @ % &quot; --    b:}</code> <code 
class="verb">a  &lt; &amp; @ % &quot; --    b</code>
 <code class="code">@w{a a a a a a a a a a a a a a a a a a a a a a a a a a a a 
a a a a a a a}</code> 
a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a<!--
 /@w -->
 <code class="code">@H{a}</code> a&#779;
 <code class="code">@H{--a}</code> &ndash;a&#779;
@@ -1441,31 +1441,31 @@ i&ndash;tem 1
    text
 </pre></div>
 
-<div class="example first-arg">
+<div class="example user-first-arg">
 <pre class="example-preformatted">example one arg
 </pre></div>
 
-<div class="example first-arg second-arg">
+<div class="example user-first-arg user-second-arg">
 <pre class="example-preformatted">example two args
 </pre></div>
 
-<div class="example first-arg second-arg third-arg">
+<div class="example user-first-arg user-second-arg user-third-arg">
 <pre class="example-preformatted">example three args
 </pre></div>
 
-<div class="example first-arg second-arg third-arg fourth-arg">
+<div class="example user-first-arg user-second-arg user-third-arg 
user-fourth-arg">
 <pre class="example-preformatted">example four args
 </pre></div>
 
-<div class="example first-arg second-arg third-arg fourth-arg fifth-arg">
+<div class="example user-first-arg user-second-arg user-third-arg 
user-fourth-arg user-fifth-arg">
 <pre class="example-preformatted">example five args
 </pre></div>
 
-<div class="example something-é-TeX">
+<div class="example user-something-é-TeX">
 <pre class="example-preformatted">The something &eacute; TeX is here.
 </pre></div>
 
-<div class="example @-at-the-end-of-line--">
+<div class="example user-@-at-the-end-of-line--">
 <pre class="example-preformatted">A @ at the end of the @example line.
 </pre></div>
 
@@ -1473,7 +1473,7 @@ i&ndash;tem 1
 <pre class="example-preformatted">example with empty args
 </pre></div>
 
-<div class="example nonempty">
+<div class="example user-nonempty">
 <pre class="example-preformatted">example with empty and non empty args mix
 </pre></div>
 
@@ -2239,8 +2239,8 @@ but , ,
 <code class="code">@url{--a,}</code> <a class="url" href="--a">--a</a>
 <code class="code">@url{,--b}</code> &ndash;b
 <code class="code">@var{--a}</code> <var class="var">&ndash;a</var>
-<code class="code">@verb{:--a:}</code> <tt class="verb">--a</tt>
-<code class="code">@verb{:a  &lt; &amp; @ % &quot; --    b:}</code> <tt 
class="verb">a  &lt; &amp; @ % &quot; --    b</tt>
+<code class="code">@verb{:--a:}</code> <code class="verb">--a</code>
+<code class="code">@verb{:a  &lt; &amp; @ % &quot; --    b:}</code> <code 
class="verb">a  &lt; &amp; @ % &quot; --    b</code>
 <code class="code">@w{a a a a a a a a a a a a a a a a a a a a a a a a a a a a 
a a a a a a a}</code> 
a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a&nbsp;a<!--
 /@w -->
 <code class="code">@H{a}</code> a&#779;
 <code class="code">@H{--a}</code> &ndash;a&#779;
@@ -2599,31 +2599,31 @@ i&ndash;tem 1
    text
 </pre></div>
 
-<div class="example first-arg">
+<div class="example user-first-arg">
 <pre class="example-preformatted">example one arg
 </pre></div>
 
-<div class="example first-arg second-arg">
+<div class="example user-first-arg user-second-arg">
 <pre class="example-preformatted">example two args
 </pre></div>
 
-<div class="example first-arg second-arg third-arg">
+<div class="example user-first-arg user-second-arg user-third-arg">
 <pre class="example-preformatted">example three args
 </pre></div>
 
-<div class="example first-arg second-arg third-arg fourth-arg">
+<div class="example user-first-arg user-second-arg user-third-arg 
user-fourth-arg">
 <pre class="example-preformatted">example four args
 </pre></div>
 
-<div class="example first-arg second-arg third-arg fourth-arg fifth-arg">
+<div class="example user-first-arg user-second-arg user-third-arg 
user-fourth-arg user-fifth-arg">
 <pre class="example-preformatted">example five args
 </pre></div>
 
-<div class="example something-é-TeX">
+<div class="example user-something-é-TeX">
 <pre class="example-preformatted">The something &eacute; TeX is here.
 </pre></div>
 
-<div class="example @-at-the-end-of-line--">
+<div class="example user-@-at-the-end-of-line--">
 <pre class="example-preformatted">A @ at the end of the @example line.
 </pre></div>
 
@@ -2631,7 +2631,7 @@ i&ndash;tem 1
 <pre class="example-preformatted">example with empty args
 </pre></div>
 
-<div class="example nonempty">
+<div class="example user-nonempty">
 <pre class="example-preformatted">example with empty and non empty args mix
 </pre></div>
 
@@ -3404,8 +3404,8 @@ but , ,
 <code class="code">@url{--a,}</code> <a class="url" href="--a">--a</a>
 <code class="code">@url{,--b}</code> --b
 <code class="code">@var{--a}</code> <var class="var">--a</var>
-<code class="code">@verb{:--a:}</code> <tt class="verb">--a</tt>
-<code class="code">@verb{:a  &lt; &amp; @ % &quot; --    b:}</code> <tt 
class="verb">a  &lt; &amp; @ % &quot; --    b</tt>
+<code class="code">@verb{:--a:}</code> <code class="verb">--a</code>
+<code class="code">@verb{:a  &lt; &amp; @ % &quot; --    b:}</code> <code 
class="verb">a  &lt; &amp; @ % &quot; --    b</code>
 <code class="code">@w{a a a a a a a a a a a a a a a a a a a a a a a a a a a a 
a a a a a a a}</code> a a a a a a a a a a a a a a a a a a a a a a a a a a a a a 
a a a a a a<!-- /@w -->
 <code class="code">@H{a}</code> a&#779;
 <code class="code">@H{--a}</code> --a&#779;
@@ -3817,37 +3817,37 @@ $">
 </pre></div>
 <pre class="example-preformatted">
 
-</pre><div class="example first-arg">
+</pre><div class="example user-first-arg">
 <pre class="example-preformatted">example one arg
 </pre></div>
 <pre class="example-preformatted">
 
-</pre><div class="example first-arg second-arg">
+</pre><div class="example user-first-arg user-second-arg">
 <pre class="example-preformatted">example two args
 </pre></div>
 <pre class="example-preformatted">
 
-</pre><div class="example first-arg second-arg third-arg">
+</pre><div class="example user-first-arg user-second-arg user-third-arg">
 <pre class="example-preformatted">example three args
 </pre></div>
 <pre class="example-preformatted">
 
-</pre><div class="example first-arg second-arg third-arg fourth-arg">
+</pre><div class="example user-first-arg user-second-arg user-third-arg 
user-fourth-arg">
 <pre class="example-preformatted">example four args
 </pre></div>
 <pre class="example-preformatted">
 
-</pre><div class="example first-arg second-arg third-arg fourth-arg fifth-arg">
+</pre><div class="example user-first-arg user-second-arg user-third-arg 
user-fourth-arg user-fifth-arg">
 <pre class="example-preformatted">example five args
 </pre></div>
 <pre class="example-preformatted">
 
-</pre><div class="example something-é-TeX">
+</pre><div class="example user-something-é-TeX">
 <pre class="example-preformatted">The something &eacute; TeX is here.
 </pre></div>
 <pre class="example-preformatted">
 
-</pre><div class="example @-at-the-end-of-line--">
+</pre><div class="example user-@-at-the-end-of-line--">
 <pre class="example-preformatted">A @ at the end of the @example line.
 </pre></div>
 <pre class="example-preformatted">
@@ -3857,7 +3857,7 @@ $">
 </pre></div>
 <pre class="example-preformatted">
 
-</pre><div class="example nonempty">
+</pre><div class="example user-nonempty">
 <pre class="example-preformatted">example with empty and non empty args mix
 </pre></div>
 <pre class="example-preformatted">



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/tp/Texinfo/Structuring.pm b/tp/Texinfo/Structuring.pm
index f839f8f022..92e9f2f7c1 100644
--- a/tp/Texinfo/Structuring.pm
+++ b/tp/Texinfo/Structuring.pm
@@ -410,7 +410,7 @@ sub check_nodes_are_referenced
   # consider nodes in @*ref commands to be referenced
   if (defined($refs)) {
     foreach my $ref (@$refs) {
-      my $node_arg = $ref->{'extra'}{'node_argument'};
+      my $node_arg = $ref->{'extra'}->{'node_argument'};
       if ($node_arg->{'node_content'}) {
         my $normalized =
            Texinfo::Convert::NodeNameNormalization::normalize_node(
@@ -1289,8 +1289,10 @@ sub print_element_directions($)
   return $result;
 }
 
 # For each internal reference command, set the 'label' key in the 'extra' 
 # hash of the reference tree element to the associated labeled tree element.
 sub associate_internal_references($$$$$)
 {
   my $registrar = shift;
@@ -1302,7 +1304,7 @@ sub associate_internal_references($$$$$)
   return if (!defined($refs));
   foreach my $ref (@$refs) {
     my $node_arg;
-    $node_arg = $ref->{'extra'}{'menu_entry_node'};
+    $node_arg = $ref->{'extra'}->{'menu_entry_node'};
     
     if (defined $node_arg) {
       if ($node_arg->{'node_content'}) {
@@ -1315,7 +1317,7 @@ sub associate_internal_references($$$$$)
       next;
     }
     
-    $node_arg = $ref->{'extra'}{'node_argument'};
+    $node_arg = $ref->{'extra'}->{'node_argument'};
     if ($node_arg->{'node_content'}) {
       my $normalized =
            Texinfo::Convert::NodeNameNormalization::normalize_node(
@@ -1537,7 +1539,7 @@ sub new_complete_node_menu
   }
 
   my $section = $node->{'extra'}->{'associated_section'};
-  my $new_menu = new_block_command (\@pending, $section, 'menu');
+  my $new_menu = new_block_command(\@pending, $section, 'menu');
 
   return $new_menu;
 }
@@ -1798,10 +1800,12 @@ information, labels or refs are obtained from a parser, 
see L<Texinfo::Parser>.
 X<C<associate_internal_references>>
 
 Verify that internal references (C<@ref> and similar without
-fourth of fifth argument) have an associated node, anchor or float.
-Set the C<label> key in the C<extra> hash of the reference tree
-element to the associated labeled tree element.  Register errors
-in I<$registrar>.
+fourth of fifth argument and menu entries) have an associated node, anchor or
+float.  Set the C<normalized> key in the C<extra> hash C<menu_entry_node> hash
+for menu entries and in the C<extra> hash C<node_argument> hash for internal
+references C<@ref> and similar @-commands.  Set the C<label> key in the
+C<extra> hash of the reference tree element to the associated labeled tree
+element.  Register errors in I<$registrar>.
 
 =item check_nodes_are_referenced($registrar, $configuration_information, 
@@ -1289,8 +1289,10 @@ sub print_element_directions($)
 }
 
-# For each internal reference command, set the 'label' key in the 'extra' 
-# hash of the reference tree element to the associated labeled tree element.
+# For each internal reference command, set the 'normalized' key in the
+# 'menu_entry_node' for menu entries, and 'node_argument' for @*ref.
+# Set the 'label' key in the 'extra' hash of the reference tree element
+# to the associated labeled tree element.
 sub associate_internal_references($$$$$)
 {
$nodes_list, $top_node, $labels, $refs)
 X<C<check_nodes_are_referenced>>